libftdi-git Archives

Subject: A library to talk to FTDI chips branch, master, updated. v1.4-29-gdb9c7eb

From: libftdi-git@xxxxxxxxxxxxxxxxxxxxxxx
To: libftdi-git@xxxxxxxxxxxxxxxxxxxxxxx
Date: Mon, 20 Jan 2020 17:54:23 +0100 (CET)
The branch, master has been updated
       via  db9c7eba8ff28219a33b5494a3d60aa487d87ef1 (commit)
      from  ae3d154b7641b120f537c6d86871371c9d75c9e9 (commit)


- Log -----------------------------------------------------------------
commit db9c7eba8ff28219a33b5494a3d60aa487d87ef1
Author: Yegor Yefremov <yegorslists@xxxxxxxxxxxxxx>
Date:   Thu Jan 16 08:42:21 2020 +0100

    Fix typos
    
    Signed-off-by: Yegor Yefremov <yegorslists@xxxxxxxxxxxxxx>

-----------------------------------------------------------------------

Summary of changes:
 cmake/FindConfuse.cmake |    2 +-
 examples/async.c        |    4 ++--
 examples/serial_test.c  |    2 +-
 examples/stream_test.c  |    4 ++--
 ftdipp/CMakeLists.txt   |    2 +-
 ftdipp/ftdi.cpp         |    2 +-
 python/examples/cbus.py |    2 +-
 src/CMakeLists.txt      |    2 +-
 src/ftdi.c              |    2 +-
 src/ftdi_i.h            |    6 +++---
 10 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/cmake/FindConfuse.cmake b/cmake/FindConfuse.cmake
index ab25eef..f6af7d5 100644
--- a/cmake/FindConfuse.cmake
+++ b/cmake/FindConfuse.cmake
@@ -6,7 +6,7 @@
 #  CONFUSE_INCLUDE_DIR - where to find confuse.h
 #  CONFUSE_INCLUDE_DIRS - confuse includes
 #  CONFUSE_LIBRARY - where to find the Confuse library
-#  CONFUSE_LIBRARIES - aditional libraries
+#  CONFUSE_LIBRARIES - additional libraries
 #  CONFUSE_ROOT_DIR - root dir (ex. /usr/local)
 
 #=============================================================================
diff --git a/examples/async.c b/examples/async.c
index 18989c1..241bb7f 100644
--- a/examples/async.c
+++ b/examples/async.c
@@ -3,7 +3,7 @@
    This program is distributed under the GPL, version 2
 */
 
-/* This programm switches to MPSSE mode, and sets and then reads back
+/* This program switches to MPSSE mode, and sets and then reads back
  * the high byte 3 times with three different values.
  * The expected read values are hard coded in ftdi_init
  * with 0x00, 0x55 and 0xaa
@@ -167,7 +167,7 @@ int main(int argc, char **argv)
             }
         }
         if (i < 1) {
-            printf("Async read unsuccessfull\n");
+            printf("Async read unsuccessful\n");
         }
     }
     printf("Read %02x %02x %02x\n", data[0], data[1], data[2]);
diff --git a/examples/serial_test.c b/examples/serial_test.c
index 289dd97..0631504 100644
--- a/examples/serial_test.c
+++ b/examples/serial_test.c
@@ -134,7 +134,7 @@ int main(int argc, char **argv)
      *
      * TODO: Make these parameters settable from the command line
      *
-     * Parameters are choosen that sending a continous stream of 0x55 
+     * Parameters are chosen that sending a continuous stream of 0x55 
      * should give a square wave
      *
      */
diff --git a/ftdipp/CMakeLists.txt b/ftdipp/CMakeLists.txt
index a9e3418..fac5bcc 100644
--- a/ftdipp/CMakeLists.txt
+++ b/ftdipp/CMakeLists.txt
@@ -14,7 +14,7 @@ include_directories(${Boost_INCLUDE_DIRS})
 # Shared library
 add_library(ftdipp1 SHARED ${cpp_sources})
 
-math(EXPR VERSION_FIXUP "${MAJOR_VERSION} + 1")    # Compatiblity with 
previous releases
+math(EXPR VERSION_FIXUP "${MAJOR_VERSION} + 1")    # Compatibility with 
previous releases
 set_target_properties(ftdipp1 PROPERTIES VERSION 
${VERSION_FIXUP}.${MINOR_VERSION}.0 SOVERSION 3)
 
 # Prevent clobbering each other during the build
diff --git a/ftdipp/ftdi.cpp b/ftdipp/ftdi.cpp
index dd777be..f82b865 100644
--- a/ftdipp/ftdi.cpp
+++ b/ftdipp/ftdi.cpp
@@ -1,5 +1,5 @@
 /***************************************************************************
-                          ftdi.cpp  -  C++ wraper for libftdi
+                          ftdi.cpp  -  C++ wrapper for libftdi
                              -------------------
     begin                : Mon Oct 13 2008
     copyright            : (C) 2008-2017 by Marek Vavruša / libftdi developers
diff --git a/python/examples/cbus.py b/python/examples/cbus.py
index 3ab9512..9c0356c 100644
--- a/python/examples/cbus.py
+++ b/python/examples/cbus.py
@@ -6,7 +6,7 @@ This program is distributed under the GPL, version 2.
 
 Demonstrate how to configure the FT230X USB UART bridge as follows:
   max_power     500 mA
-  CBUS3         Drive 1 (accomodate PCB error)
+  CBUS3         Drive 1 (accommodate PCB error)
 """
 
 import sys
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 9fd86a6..17b3617 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -23,7 +23,7 @@ set(c_headers     ${CMAKE_CURRENT_SOURCE_DIR}/ftdi.h CACHE 
INTERNAL "List of c h
 
 add_library(ftdi1 SHARED ${c_sources})
 
-math(EXPR VERSION_FIXUP "${MAJOR_VERSION} + 1")    # Compatiblity with 
previous releases
+math(EXPR VERSION_FIXUP "${MAJOR_VERSION} + 1")    # Compatibility with 
previous releases
 set_target_properties(ftdi1 PROPERTIES VERSION 
${VERSION_FIXUP}.${MINOR_VERSION}.0 SOVERSION 2)
 # Prevent clobbering each other during the build
 set_target_properties ( ftdi1 PROPERTIES CLEAN_DIRECT_OUTPUT 1 )
diff --git a/src/ftdi.c b/src/ftdi.c
index 9495fb5..d2f4ce4 100644
--- a/src/ftdi.c
+++ b/src/ftdi.c
@@ -1992,7 +1992,7 @@ int ftdi_write_data_get_chunksize(struct ftdi_context 
*ftdi, unsigned int *chunk
 /**
     Reads data in chunks (see ftdi_read_data_set_chunksize()) from the chip.
 
-    Automatically strips the two modem status bytes transfered during every 
read.
+    Automatically strips the two modem status bytes transferred during every 
read.
 
     \param ftdi pointer to ftdi_context
     \param buf Buffer to store data in
diff --git a/src/ftdi_i.h b/src/ftdi_i.h
index e7355aa..f62795f 100644
--- a/src/ftdi_i.h
+++ b/src/ftdi_i.h
@@ -91,11 +91,11 @@ struct ftdi_eeprom
     /* Special function of FT232R/FT232H devices (and possibly others as well) 
*/
     /** CBUS pin function. See CBUS_xxx defines. */
     int cbus_function[10];
-    /** Select hight current drive on R devices. */
+    /** Select high current drive on R devices. */
     int high_current;
-    /** Select hight current drive on A channel (2232C */
+    /** Select high current drive on A channel (2232C */
     int high_current_a;
-    /** Select hight current drive on B channel (2232C). */
+    /** Select high current drive on B channel (2232C). */
     int high_current_b;
     /** Select inversion of data lines (bitmask). */
     int invert;


hooks/post-receive
diff --git a/examples/stream_test.c b/examples/stream_test.c
index 43abea9..10e0977 100644
--- a/examples/stream_test.c
+++ b/examples/stream_test.c
@@ -10,7 +10,7 @@
  * 3* uint32_t dont_care
  *
  * After start, data will be read in streaming until the program is aborted
  * Progess information wil be printed out
  * If a filename is given on the command line, the data read will be
  * written to that file
  *
@@ -52,7 +52,7 @@ usage(const char *argv0)
            "[-n] don't check for special block structure\n"
            "\n"
            "If some filename is given, write data read to that file\n"
-           "Progess information is printed each second\n"
+           "Progress information is printed each second\n"
            "Abort with ^C\n"
            "\n"
            "Options:\n"
@@ -10,7 +10,7 @@
  *
  * After start, data will be read in streaming until the program is aborted
- * Progess information wil be printed out
+ * Progress information will be printed out
  * If a filename is given on the command line, the data read will be
  * written to that file
-- 
A library to talk to FTDI chips

--
libftdi-git - see http://www.intra2net.com/en/developer/libftdi for details.
To unsubscribe send a mail to libftdi-git+unsubscribe@xxxxxxxxxxxxxxxxxxxxxxx   

Current Thread
  • A library to talk to FTDI chips branch, master, updated. v1.4-29-gdb9c7eb, libftdi-git <=